@@ -22,3 +22,6 @@ finally:
     del version, PackageNotFoundError
 
 from .MultiAssayExperiment import MultiAssayExperiment
+from .io.anndata import readH5AD, fromAnnData
+from .io.mudata import fromMuData
+from .io.interface import makeMAE
